#ifndef __PCE_INPUT_GAMEPAD_H
#define __PCE_INPUT_GAMEPAD_H

namespace MDFN_IEN_PCE
{
 MDFN_HIDE extern const IDIISG PCE_GamepadIDII;
 PCE_Input_Device *PCEINPUT_MakeGamepad(void);
};

#endif
